==> huaweicloudsdkeihealth-3.1.54-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/create_study_job_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateStudyJobRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'eihealth_project_id': 'str',
        'study_id': 'str',
        'body': 'CreateStudyJobReq'
    }

    attribute_map = {
        'eihealth_project_id': 'eihealth_project_id',
        'study_id': 'study_id',
        'body': 'body'
    }

    def __init__(self, eihealth_project_id=None, study_id=None, body=None):
        """CreateStudyJobRequest

        The model defined in huaweicloud sdk

        :param eihealth_project_id: 医疗智能体平台项目ID，您可以在EIHealth平台单击所需的项目名称，进入项目设置页面查看。
        :type eihealth_project_id: str
        :param study_id: study_id
        :type study_id: str
        :param body: Body of the CreateStudyJobRequest
        :type body: :class:`huaweicloudsdkeihealth.v1.CreateStudyJobReq`
        """
        
        

        self._eihealth_project_id = None
        self._study_id = None
        self._body = None
        self.discriminator = None

        self.eihealth_project_id = eihealth_project_id
        self.study_id = study_id
        if body is not None:
            self.body = body

    @property
    def eihealth_project_id(self):
        """Gets the eihealth_project_id of this CreateStudyJobRequest.

        医疗智能体平台项目ID，您可以在EIHealth平台单击所需的项目名称，进入项目设置页面查看。

        :return: The eihealth_project_id of this CreateStudyJobRequest.
        :rtype: str
        """
        return self._eihealth_project_id

    @eihealth_project_id.setter
    def eihealth_project_id(self, eihealth_project_id):
        """Sets the eihealth_project_id of this CreateStudyJobRequest.

        医疗智能体平台项目ID，您可以在EIHealth平台单击所需的项目名称，进入项目设置页面查看。

        :param eihealth_project_id: The eihealth_project_id of this CreateStudyJobRequest.
        :type eihealth_project_id: str
        """
        self._eihealth_project_id = eihealth_project_id

    @property
    def study_id(self):
        """Gets the study_id of this CreateStudyJobRequest.

        study_id

        :return: The study_id of this CreateStudyJobRequest.
        :rtype: str
        """
        return self._study_id

    @study_id.setter
    def study_id(self, study_id):
        """Sets the study_id of this CreateStudyJobRequest.

        study_id

        :param study_id: The study_id of this CreateStudyJobRequest.
        :type study_id: str
        """
        self._study_id = study_id

    @property
    def body(self):
        """Gets the body of this CreateStudyJobRequest.

        :return: The body of this CreateStudyJobRequest.
        :rtype: :class:`huaweicloudsdkeihealth.v1.CreateStudyJobReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateStudyJobRequest.

        :param body: The body of this CreateStudyJobRequest.
        :type body: :class:`huaweicloudsdkeihealth.v1.CreateStudyJobReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateStudyJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeihealth-3.1.138-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/create_study_job_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateStudyJobRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'eihealth_project_id': 'str',
        'study_id': 'str',
        'body': 'CreateStudyJobReq'
    }

    attribute_map = {
        'eihealth_project_id': 'eihealth_project_id',
        'study_id': 'study_id',
        'body': 'body'
    }

    def __init__(self, eihealth_project_id=None, study_id=None, body=None):
        """CreateStudyJobRequest

        The model defined in huaweicloud sdk

        :param eihealth_project_id: 平台项目ID，您可以在平台单击所需的项目名称，进入项目设置页面查看。
        :type eihealth_project_id: str
        :param study_id: study_id
        :type study_id: str
        :param body: Body of the CreateStudyJobRequest
        :type body: :class:`huaweicloudsdkeihealth.v1.CreateStudyJobReq`
        """
        
        

        self._eihealth_project_id = None
        self._study_id = None
        self._body = None
        self.discriminator = None

        self.eihealth_project_id = eihealth_project_id
        self.study_id = study_id
        if body is not None:
            self.body = body

    @property
    def eihealth_project_id(self):
        """Gets the eihealth_project_id of this CreateStudyJobRequest.

        平台项目ID，您可以在平台单击所需的项目名称，进入项目设置页面查看。

        :return: The eihealth_project_id of this CreateStudyJobRequest.
        :rtype: str
        """
        return self._eihealth_project_id

    @eihealth_project_id.setter
    def eihealth_project_id(self, eihealth_project_id):
        """Sets the eihealth_project_id of this CreateStudyJobRequest.

        平台项目ID，您可以在平台单击所需的项目名称，进入项目设置页面查看。

        :param eihealth_project_id: The eihealth_project_id of this CreateStudyJobRequest.
        :type eihealth_project_id: str
        """
        self._eihealth_project_id = eihealth_project_id

    @property
    def study_id(self):
        """Gets the study_id of this CreateStudyJobRequest.

        study_id

        :return: The study_id of this CreateStudyJobRequest.
        :rtype: str
        """
        return self._study_id

    @study_id.setter
    def study_id(self, study_id):
        """Sets the study_id of this CreateStudyJobRequest.

        study_id

        :param study_id: The study_id of this CreateStudyJobRequest.
        :type study_id: str
        """
        self._study_id = study_id

    @property
    def body(self):
        """Gets the body of this CreateStudyJobRequest.

        :return: The body of this CreateStudyJobRequest.
        :rtype: :class:`huaweicloudsdkeihealth.v1.CreateStudyJobReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateStudyJobRequest.

        :param body: The body of this CreateStudyJobRequest.
        :type body: :class:`huaweicloudsdkeihealth.v1.CreateStudyJobReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateStudyJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
